#

##

###

##

###

###

###

##

    	fees

    	steps

    		step 1
    			constant fees for each move kind that can change based on votes.

    	possibilities

    		variable fees
    			if fees become variable, could have an upper and lower limit here

    		fee pool for withdrawing aggregate of fractional fees over time
    			This would require a fee to withdraw from as well though

    		bids

    	voting on fee level